# Copyright (C) 2012 Martin Albisetti - argentina@gmail.com

"""
Tests for the task manager views.
"""

from django.test import TestCase
from django.contrib.auth.models import User

from models import Team
from views import (
    _create_task,
    get_task_by_id,
    get_all_tasks,
    get_tasks_by_team,
)


class ViewsTest(TestCase):

    def setUp(self):
        self.user = User.objects.create(username='test_user')
        self.user2 = User.objects.create(username='test_user2')
        self.user3 = User.objects.create(username='test_user3')
        self.team = Team.objects.create(name='team1')
        self.team2 = Team.objects.create(name='team2')

    def tearDown(self):
        self.user.delete()

    def _create_test_task(self, title='Test title', owner=None,
                        position=1, assigned_to=None):
        """Simplify creating test tasks."""
        if owner is None:
            owner = self.team
        t = _create_task(title=title, owner=owner, position=position,
            assigned_to=assigned_to)
        return t

    def test__create_task_simple(self):
        """Test that we can create a task."""
        t = self._create_test_task()
        self.assertEquals(t.id, 1)

    def test_get_task_by_id(self):
        """"""
        t = self._create_test_task(assigned_to=[self.user2, self.user3])
        t = get_task_by_id(1)
        self.assertEquals(t.id, 1)
        self.assertEquals(t.title, 'Test title')
        self.assertEquals(t.owner.id, self.user.id)
        self.assertEquals(t.assigned_to.count(), 2)
        self.assertEquals(t.assigned_to.all()[0].id, self.user2.id)
        self.assertEquals(t.assigned_to.all()[1].id, self.user3.id)

    def test_get_all_tasks(self):
        """"""
        self._create_test_task()
        # Yesterday
        self._create_test_task(title='Test title2', position=0)
        # Tomorrow
        self._create_test_task(title='Test title3', position=2)
        ts = get_all_tasks()
        self.assertEquals(ts.count(), 3)
        #XXX: fix start_date
        # Only today and later
        #ts = get_all_tasks(from_date=datetime.datetime.now())
        #self.assertEquals(ts.count(), 2)

    def test_get_tasks_by_team(self):
        """"""
        # team1 is the default
        t1 = self._create_test_task()
        t2 = self._create_test_task(owner=self.team2)
        teams = get_tasks_by_team()
        self.assertEquals(teams, {self.team.name: [t1], self.team2.name: [t2]})
        t3 = self._create_test_task(owner=self.team2)
        teams = get_tasks_by_team()
        self.assertEquals(teams, {self.team.name: [t1],
                                  self.team2.name: [t2, t3]})
