# Copyright (C) 2012 Martin Albisetti - argentina@gmail.com

"""Views for the task manager."""


import datetime
from models import Task

from django.template import Context, loader
from django.http import HttpResponse


def index(request):
    """"""
    template = loader.get_template('index.html')
    teams = get_tasks_by_team()
    c = Context({
        'teams': teams,
    })
    return HttpResponse(template.render(c))


def move_task(request):
    """"""
    new_pos = request.GET['new_pos']
    task_id = request.GET['task_id']
    t = Task.objects.get(pk=task_id)
    t.position = new_pos
    t.save()
    return HttpResponse()


def _create_task(title, owner, position=None, size_days=1,
                    description=None, assigned_to=[]):
    """"""
    task = Task(title=title,
                description=description,
                owner=owner,
                position=position,
                size_days=size_days,
                when_created=datetime.datetime.now())
    task.save()
    if assigned_to:
        for user in assigned_to:
            task.assigned_to.add(user)
    return task


def get_task_by_id(id):
    """"""
    t = Task.objects.get(pk=id)
    return t


def get_tasks_by_team(from_date=None):
    """"""
    teams = {}
    if from_date is None:
        tasks = Task.objects.all()
    else:
        #XXX: Will need to convert dates to positions
#        tasks = Task.objects.filter(start_date__gte=from_date)
        tasks = Task.objects.all()
    for task in tasks.order_by('owner', 'position'):
        try:
            teams[task.owner.name].append(task)
        except KeyError:
            teams[task.owner.name] = []
            teams[task.owner.name].append(task)
    return teams


def get_all_tasks(from_date=None):
    """"""
    if from_date is None:
        tasks = Task.objects.all().order_by('position')
    else:
        #XXX: Will need to convert dates to positions
#        tasks = Task.objects.filter(
#            start_date__gte=from_date).order_by('position')
        tasks = Task.objects.all().order_by('position')
    return tasks
